@@ -1,11 +1,11 @@
 from svglib.svglib import svg2rlg
 from reportlab.graphics import renderPM
 from PIL import Image
-from icon_xml import get_xml_bytes
+from simpleicons.icon_xml import get_xml_bytes
 from io import BytesIO
 from typing import Tuple
 
-def icon_to_img(icon_xml: bytes, bg: int=0xffffff, scale: Tuple[int, int]=(1, 1)) -> Image:
+def icon_to_image(icon_xml: bytes, bg: int=0xffffff, scale: Tuple[int, int]=(1, 1)) -> Image:
     """Convert icon to PIL image.
 
     Args:
